@@ -14,7 +14,7 @@ from __future__ import absolute_import, division, print_function
 
 # Built-in imports
 from collections import OrderedDict as odict
-import os
+from glob import glob
 from os import path
 from textwrap import dedent
 
@@ -22,7 +22,10 @@ from textwrap import dedent
 from colorspacious import cspace_converter
 from matplotlib import cm as mplcm
 from matplotlib.collections import LineCollection
-from matplotlib.colors import ListedColormap as LC
+from matplotlib.colors import ListedColormap as LC, to_hex, to_rgb
+from matplotlib.legend import Legend
+from matplotlib.legend_handler import HandlerBase
+from matplotlib.image import AxesImage
 import matplotlib.pyplot as plt
 import numpy as np
 from six import string_types
@@ -31,91 +34,35 @@ from six import string_types
 from cmasher import cm as cmrcm
 
 # All declaration
-__all__ = ['create_cmap_overview', 'get_bibtex', 'import_cmaps']
+__all__ = ['create_cmap_overview', 'get_bibtex', 'get_cmap_type',
+           'get_sub_cmap', 'import_cmaps', 'register_cmap',
+           'set_cmap_legend_entry', 'take_cmap_colors']
+
+
+# %% HELPER CLASSES
+# Define legend handler class for artists that use colormaps
+class _HandlerColorPolyCollection(HandlerBase):
+    # Override create_artists to create an AxesImage resembling a colormap
+    def create_artists(self, legend, artist, xdescent, ydescent, width, height,
+                       fontsize, trans):
+        # Obtain the Axes object of this legend
+        ax = legend.axes
+
+        # Obtain the colormap of the artist
+        cmap = artist.cmap
+
+        # Create an AxesImage to contain the colormap with proper dimensions
+        image = AxesImage(ax, cmap=cmap, transform=trans,
+                          extent=[xdescent, width, ydescent, height])
+
+        # Set the data of the image
+        image.set_data(np.arange(cmap.N)[np.newaxis, ...])
+
+        # Return the AxesImage object
+        return([image])
 
 
 # %% HELPER FUNCTIONS
-# This function determines the colormap type of a given colormap
-def _get_cm_type(cmap):
-    """
-    Checks what the colormap type (sequential; diverging; cyclic; qualitative;
-    misc) of the provided `cmap` is and returns it.
-
-    Parameters
-    ----------
-    cmap : str or :obj:`~matplotlib.colors.Colormap` object
-        The registered name of the colormap in *MPL* or its corresponding
-        :obj:`~matplotlib.colors.Colormap` object.
-
-    Returns
-    -------
-    cm_type : {'sequential'; 'diverging'; 'cyclic'; 'qualitative'; 'misc'}
-        A string stating which of the defined colormap types the provided
-        `cmap` has.
-
-    """
-
-    # Obtain the colormap
-    cmap = mplcm.get_cmap(cmap)
-
-    # Get array of all values for which a colormap value is requested
-    x = np.linspace(0, 1, cmap.N)
-
-    # Get RGB values for colormap
-    rgb = cmap(x)[:, :3]
-
-    # Get lightness values of colormap
-    lab = cspace_converter("sRGB1", "CAM02-UCS")(rgb)
-    L = lab[:, 0]
-    diff_L = np.diff(L)
-
-    # Obtain central values of lightness
-    N = cmap.N-1
-    central_i = [int(np.floor(N/2)), int(np.ceil(N/2))]
-    diff_L0 = np.diff(L[:central_i[0]+1])
-    diff_L1 = np.diff(L[central_i[1]:])
-
-    # Obtain perceptual differences of last two and first two values
-    lab_red = lab[[-2, -1, 0, 1]]
-    deltas = np.sqrt(np.sum(np.diff(lab_red, axis=0)**2, axis=-1))
-
-    # Check the statistics of cmap and determine the colormap type
-    # QUALITATIVE
-    # If the colormap has less than 40 values, assume it is qualitative
-    if(cmap.N < 40):
-        return('qualitative')
-
-    # MISC 1
-    # If the colormap has plateaus in lightness, it is misc
-    elif np.any(np.isclose(diff_L0, 0)) or np.any(np.isclose(diff_L1, 0)):
-        return('misc')
-
-    # SEQUENTIAL
-    # If the lightness values always increase or decrease, it is sequential
-    elif (np.isclose(np.abs(np.sum(diff_L)), np.sum(np.abs(diff_L))) and
-          not np.any(np.isclose(diff_L, 0))):
-        return('sequential')
-
-    # DIVERGING
-    # If the lightness values have a central extreme and sequential sides
-    # Then it is diverging
-    elif (np.isclose(np.abs(np.sum(diff_L0)), np.sum(np.abs(diff_L0))) and
-          np.isclose(np.abs(np.sum(diff_L1)), np.sum(np.abs(diff_L1)))):
-        # If the perceptual difference between the last and first value is
-        # comparable to the other perceptual differences, it is cyclic
-        if np.all(np.abs(np.diff(deltas)) < deltas[::2]):
-            return('cyclic')
-
-        # Otherwise, it is a normal diverging colormap
-        else:
-            return('diverging')
-
-    # MISC 2
-    # If none of the criteria above apply, it is misc
-    else:
-        return('misc')
-
-
 # Define function for obtaining the sorting order for lightness ranking
 def _get_cmap_lightness_rank(cmap):
     """
@@ -125,18 +72,19 @@ def _get_cmap_lightness_rank(cmap):
     Parameters
     ----------
     cmap : str or :obj:`~matplotlib.colors.Colormap` object
-        The registered name of the colormap in *MPL* or its corresponding
-        :obj:`~matplotlib.colors.Colormap` object.
+        The registered name of the colormap in :mod:`matplotlib.cm` or its
+        corresponding :obj:`~matplotlib.colors.Colormap` object.
 
     Returns
     -------
     L_start : float
         The starting lightness value of `cmap`.
+        For diverging colormaps, this is the central lightness value.
+    L_rng : float
+        The lightness range (L_max-L_min) of `cmap`.
     L_rmse : float
         The RMSE of the lightness profile of `cmap`.
         For diverging colormaps, this is the max RMSE of either half.
-    L_rng : float
-        The lightness range (L_max-L_min) of `cmap`.
     name : str
         The name of `cmap`.
 
@@ -145,11 +93,8 @@ def _get_cmap_lightness_rank(cmap):
     # Obtain the colormap
     cmap = mplcm.get_cmap(cmap)
 
-    # Get array of all values for which a colormap value is requested
-    x = np.linspace(0, 1, cmap.N)
-
     # Get RGB values for colormap
-    rgb = cmap(x)[:, :3]
+    rgb = cmap(np.arange(cmap.N))[:, :3]
 
     # Get lightness values of colormap
     lab = cspace_converter("sRGB1", "CAM02-UCS")(rgb)
@@ -160,23 +105,28 @@ def _get_cmap_lightness_rank(cmap):
     derivs = (cmap.N-1)*deltas
 
     # Determine the RMSE of the lightness profile
-    if _get_cm_type(cmap) in ('diverging', 'cyclic'):
+    if get_cmap_type(cmap) in ('diverging', 'cyclic'):
         # If cmap is diverging, calculate RMSE of both halves
         central_i = [int(np.floor(cmap.N/2)), int(np.ceil(cmap.N/2))]
         L_rmse = np.max([np.around(np.std(derivs[:central_i[0]]), 1),
                          np.around(np.std(derivs[central_i[1]:]), 1)])
+
+        # Calculate central lightness value
+        L_start = np.around(np.average(L[central_i]), 1)
     else:
         # Else, take RMSE of entire lightness profile
         L_rmse = np.around(np.std(derivs), 1)
 
-    # Determine start and range
-    L_start = np.around(L[0], 1)
+        # Calculate starting lightness value
+        L_start = np.around(L[0], 1)
+
+    # Determine range
     L_min = np.around(np.min(L), 1)
     L_max = np.around(np.max(L), 1)
     L_rng = np.around(np.abs(L_max-L_min), 1)
 
     # Return contributions to the rank
-    return(L_start, L_rmse, L_rng, cmap.name)
+    return(L_start, L_rng, L_rmse, cmap.name)
 
 
 # %% FUNCTIONS
@@ -207,7 +157,7 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
         name.
         If 'lightness', the colormaps are sorted on their starting lightness
         and their lightness range.
-    plot_profile : bool or int. Default: False
+    plot_profile : bool or float. Default: False
         Whether the lightness profiles of all colormaps should be plotted. If
         not *False*, the lightness profile of a colormap is plotted on top of
         its gray-scale version and `plot_profile` is used for setting the alpha
@@ -217,7 +167,8 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
     Notes
     -----
     The colormaps in `cmaps` can either be provided as their registered name in
-    *MPL*, or their corresponding :obj:`~matplotlib.colors.Colormap` object.
+    :mod:`matplotlib.cm`, or their corresponding
+    :obj:`~matplotlib.colors.Colormap` object.
     Any provided reversed colormaps (colormaps that end their name with '_r')
     are ignored.
 
@@ -274,7 +225,7 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
 
             # Loop over all cmaps and remove reversed versions
             for cmap in cmaps:
-                cm_type = _get_cm_type(cmap)
+                cm_type = get_cmap_type(cmap)
                 if isinstance(cmap, string_types):
                     if not cmap.endswith('_r'):
                         cmaps_dict[cm_type].append(mplcm.get_cmap(cmap))
@@ -295,13 +246,13 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
         for key, value in cmaps_dict.items():
             # If this cm_type has at least 1 colormap, sort and add them
             if value:
-                # Sort this cm_type on name
-                value.sort(key=lambda x: x.name)
-
                 # Sort on lightness if requested and this cm_type is compatible
                 if((sort.lower() == 'lightness') and
                    (key not in ('qualitative', 'misc'))):
                     value.sort(key=_get_cmap_lightness_rank)
+                # Else, sort on name
+                else:
+                    value.sort(key=lambda x: x.name)
 
                 # Add to list
                 cmaps_list.append(key)
@@ -310,9 +261,10 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
     # Else, a list is used
     else:
         # Sort the colormaps
-        cmaps_list.sort(key=lambda x: x.name)
         if(sort.lower() == 'lightness'):
             cmaps_list.sort(key=_get_cmap_lightness_rank)
+        else:
+            cmaps_list.sort(key=lambda x: x.name)
 
     # Obtain the colorspace converter for showing cmaps in grey-scale
     cspace_convert = cspace_converter("sRGB1", "CAM02-UCS")
@@ -350,7 +302,7 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
         # Else, this is a colormap
         else:
             # Get array of all values for which a colormap value is requested
-            x = np.linspace(0, 1, cmap.N)
+            x = np.arange(cmap.N)
 
             # Get RGB values for colormap
             rgb = cmap(x)[:, :3]
@@ -371,9 +323,8 @@ def create_cmap_overview(cmaps=None, savefig=None, use_types=True,
             # Check if the lightness profile was requested
             if plot_profile and (cm_type != 'qualitative'):
                 # Determine the points that need to be plotted
-                plot_x = np.arange(cmap.N)
                 plot_L = -(L-0.5)
-                points = np.stack([plot_x, plot_L], axis=1)
+                points = np.stack([x, plot_L], axis=1)
 
                 # Determine the colors that each point must have
                 # Use black for L >= 0.5 and white for L <= 0.5.
@@ -473,6 +424,150 @@ def get_bibtex():
     print(bibtex.strip())
 
 
+# This function determines the colormap type of a given colormap
+def get_cmap_type(cmap):
+    """
+    Checks what the colormap type (sequential; diverging; cyclic; qualitative;
+    misc) of the provided `cmap` is and returns it.
+
+    Parameters
+    ----------
+    cmap : str or :obj:`~matplotlib.colors.Colormap` object
+        The registered name of the colormap in :mod:`matplotlib.cm` or its
+        corresponding :obj:`~matplotlib.colors.Colormap` object.
+
+    Returns
+    -------
+    cm_type : {'sequential'; 'diverging'; 'cyclic'; 'qualitative'; 'misc'}
+        A string stating which of the defined colormap types the provided
+        `cmap` has.
+
+    """
+
+    # Obtain the colormap
+    cmap = mplcm.get_cmap(cmap)
+
+    # Get RGB values for colormap
+    rgb = cmap(np.arange(cmap.N))[:, :3]
+
+    # Get lightness values of colormap
+    lab = cspace_converter("sRGB1", "CAM02-UCS")(rgb)
+    L = lab[:, 0]
+    diff_L = np.diff(L)
+
+    # Obtain central values of lightness
+    N = cmap.N-1
+    central_i = [int(np.floor(N/2)), int(np.ceil(N/2))]
+    diff_L0 = np.diff(L[:central_i[0]+1])
+    diff_L1 = np.diff(L[central_i[1]:])
+
+    # Obtain perceptual differences of last two and first two values
+    lab_red = lab[[-2, -1, 0, 1]]
+    deltas = np.sqrt(np.sum(np.diff(lab_red, axis=0)**2, axis=-1))
+
+    # Check the statistics of cmap and determine the colormap type
+    # QUALITATIVE
+    # If the colormap has less than 40 values, assume it is qualitative
+    if(cmap.N < 40):
+        return('qualitative')
+
+    # MISC 1
+    # If the colormap has only a single lightness, it is misc
+    elif np.allclose(diff_L, 0):
+        return('misc')
+
+    # SEQUENTIAL
+    # If the lightness values always increase or decrease, it is sequential
+    elif np.isclose(np.abs(np.sum(diff_L)), np.sum(np.abs(diff_L))):
+        return('sequential')
+
+    # DIVERGING
+    # If the lightness values have a central extreme and sequential sides
+    # Then it is diverging
+    elif (np.isclose(np.abs(np.sum(diff_L0)), np.sum(np.abs(diff_L0))) and
+          np.isclose(np.abs(np.sum(diff_L1)), np.sum(np.abs(diff_L1)))):
+        # If the perceptual difference between the last and first value is
+        # comparable to the other perceptual differences, it is cyclic
+        if(np.all(np.abs(np.diff(deltas)) < deltas[::2]) and
+           np.diff(deltas[::2])):
+            return('cyclic')
+
+        # Otherwise, it is a normal diverging colormap
+        else:
+            return('diverging')
+
+    # MISC 2
+    # If none of the criteria above apply, it is misc
+    else:
+        return('misc')
+
+
+# Function create a colormap using a subset of the colors in an existing one
+def get_sub_cmap(cmap, start, stop):
+    """
+    Creates a :obj:`~matplotlib.cm.ListedColormap` object using the colors in
+    the range `[start, stop]` of the provided `cmap` and returns it.
+
+    This function can be used to create a colormap that only uses a portion of
+    an existing colormap.
+
+    .. versionadded:: 1.3.2
+
+    Parameters
+    ----------
+    cmap : str or :obj:`~matplotlib.colors.Colormap` object
+        The registered name of the colormap in :mod:`matplotlib.cm` or its
+        corresponding :obj:`~matplotlib.colors.Colormap` object.
+    start, stop : float
+        The normalized range of the colors in `cmap` that must be in the sub
+        colormap.
+
+    Returns
+    -------
+    sub_cmap : :obj:`~matplotlib.colors.ListedColormap`
+        The created colormap that uses a subset of the colors in `cmap`.
+
+    Example
+    -------
+    Creating a colormap using the first 80% of the 'rainforest' colormap::
+
+        >>> get_sub_cmap('cmr.rainforest', 0, 0.8)
+
+    Notes
+    -----
+    As it can create artifacts, this function does not interpolate between the
+    colors in `cmap` to fill up the space. Therefore, using values for `start`
+    and `stop` that are too close to each other, may result in a colormap that
+    contains too few different colors to be smooth.
+    It is recommended to use at least 50% of a colormap for optimal results.
+
+    Any colormaps created using this function is not registered in either
+    *CMasher* or *MPL*.
+
+    """
+
+    # Obtain the colormap
+    cmap = mplcm.get_cmap(cmap)
+
+    # Check if provided start and stop are valid
+    if not ((0 <= start <= 1) and (0 <= stop <= 1)):
+        raise ValueError("Input arguments 'start' and 'stop' do not contain "
+                         "normalized values!")
+
+    # Convert start and stop to their integer indices
+    start = int(np.floor(start*cmap.N))
+    stop = int(np.ceil(stop*cmap.N))
+
+    # Obtain all colors that are required for the new colormap
+    colors = cmap(np.arange(start, stop))[:, :3].tolist()
+
+    # Create new colormap
+    sub_cmap = LC(colors, cmap.name+'_sub', N=stop-start)
+
+    # Return sub_cmap
+    return(sub_cmap)
+
+
 # Function to import all custom colormaps in a file or directory
 def import_cmaps(cmap_path):
     """
@@ -482,6 +577,9 @@ def import_cmaps(cmap_path):
     registering them in the :mod:`matplotlib.cm` module.
     Both the imported colormap and its reversed version will be registered.
 
+    If a provided colormap is a 'cyclic' colormap, its shifted version will
+    also be registered.
+
     Parameters
     ----------
     cmap_path : str
@@ -535,12 +633,9 @@ def import_cmaps(cmap_path):
         # Set cm_files to be the sole read-in file
         cm_files = [cmap_file]
     else:
-        # If directory, obtain the names of all files in cmap_path
+        # If directory, obtain the names of all colormap files in cmap_path
         cmap_dir = cmap_path
-        filenames = next(os.walk(cmap_dir))[2]
-
-        # Extract the files with defined colormaps
-        cm_files = [name for name in filenames if name.startswith('cm_')]
+        cm_files = list(map(path.basename, glob("%s/cm_*" % (cmap_dir))))
         cm_files.sort()
 
     # Read in all the defined colormaps, transform and register them
@@ -556,7 +651,7 @@ def import_cmaps(cmap_path):
         try:
             # If file is a NumPy binary file
             if(ext_str == '.npy'):
-                colorlist = np.load(cm_file_path).tolist()
+                rgb = np.load(cm_file_path)
 
             # If file is viscm source file
             elif(ext_str == '.jscm'):
@@ -578,39 +673,26 @@ def import_cmaps(cmap_path):
                                            cmtype=cmap.cmtype,
                                            method=cmap.method,
                                            **cmap.params)
-                    rgb, _ = v.cmap_model.get_sRGB(num=256)
-                    colorlist = rgb.tolist()
+                    rgb, _ = v.cmap_model.get_sRGB()
 
             # If file is anything else
             else:
-                colorlist = np.genfromtxt(cm_file_path).tolist()
+                rgb = np.genfromtxt(cm_file_path, dtype=None, encoding=None)
 
-            # Transform colorlist into a Colormap
-            cmap_mpl = LC(colorlist, 'cmr.'+cm_name, N=len(colorlist))
-            cmap_cmr = LC(colorlist, cm_name, N=len(colorlist))
-            cmap_mpl_r = cmap_mpl.reversed()
-            cmap_cmr_r = cmap_cmr.reversed()
+            # Register colormap
+            register_cmap(cm_name, rgb)
 
-            # Test that the colormaps can be called
-            cmap_mpl(1)
-            cmap_mpl_r(1)
+            # Check if provided cmap is a cyclic colormap
+            # If so, obtain its shifted (reversed) versions as well
+            if(get_cmap_type('cmr.'+cm_name) == 'cyclic'):
+                # Determine the central value index of the colormap
+                idx = len(rgb)//2
 
-            # Determine the cm_type of the colormap
-            cm_type = _get_cm_type(cmap_mpl)
+                # Shift the entire colormap by this index
+                rgb_s = np.concatenate([rgb[idx:], rgb[:idx]], axis=0)
 
-            # Add cmap to matplotlib's cmap list
-            mplcm.register_cmap(cmap=cmap_mpl)
-            setattr(cmrcm, cmap_cmr.name, cmap_cmr)
-            cmrcm.__all__.append(cmap_cmr.name)
-            cmrcm.cmap_d[cmap_cmr.name] = cmap_cmr
-            cmrcm.cmap_cd[cm_type][cmap_cmr.name] = cmap_cmr
-
-            # Add reversed cmap to matplotlib's cmap list
-            mplcm.register_cmap(cmap=cmap_mpl_r)
-            setattr(cmrcm, cmap_cmr_r.name, cmap_cmr_r)
-            cmrcm.__all__.append(cmap_cmr_r.name)
-            cmrcm.cmap_d[cmap_cmr_r.name] = cmap_cmr_r
-            cmrcm.cmap_cd[cm_type][cmap_cmr_r.name] = cmap_cmr_r
+                # Register this colormap as well
+                register_cmap(cm_name+'_shifted', rgb_s)
 
         # If any error is raised, reraise it
         except Exception as error:
@@ -618,5 +700,192 @@ def import_cmaps(cmap_path):
                              % (cm_name, error))
 
 
+# Function to register a custom colormap in MPL and CMasher
+def register_cmap(name, data):
+    """
+    Creates a :obj:`~matplotlib.colors.ListedColormap` object using the
+    provided `name` and `data`, and registers the colormap in the
+    :mod:`cmasher.cm` and :mod:`matplotlib.cm` modules.
+    A reversed version of the colormap will be registered as well.
+
+    Parameters
+    ----------
+    name : str
+        The name that this colormap must have.
+    data : 2D array_like of {float; int} with shape `(N, 3)`
+        An array containing the RGB values of all segments in the colormap.
+        If int, the array contains 8-bit RGB values.
+        If float, the array contains normalized RGB values.
+
+    Note
+    ----
+    In *MPL*, the colormap will have the added 'cmr.' prefix to avoid name
+    clashes.
+
+    """
+
+    # Convert provided data to a NumPy array
+    cm_data = np.array(data, ndmin=2)
+
+    # Check the type of the data
+    if issubclass(cm_data.dtype.type, np.integer):
+        # If the values are integers, divide them by 255
+        cm_data = cm_data/255
+
+    # Convert cm_data to a list
+    colorlist = cm_data.tolist()
+
+    # Transform colorlist into a Colormap
+    cmap_N = len(colorlist)
+    cmap_mpl = LC(colorlist, 'cmr.'+name, N=cmap_N)
+    cmap_cmr = LC(colorlist, name, N=cmap_N)
+    cmap_mpl_r = cmap_mpl.reversed()
+    cmap_cmr_r = cmap_cmr.reversed()
+
+    # Test that the colormaps can be called
+    cmap_mpl(1)
+    cmap_mpl_r(1)
+
+    # Determine the cm_type of the colormap
+    cm_type = get_cmap_type(cmap_mpl)
+
+    # Add cmap to matplotlib's cmap list
+    mplcm.register_cmap(cmap=cmap_mpl)
+    setattr(cmrcm, cmap_cmr.name, cmap_cmr)
+    cmrcm.__all__.append(cmap_cmr.name)
+    cmrcm.cmap_d[cmap_cmr.name] = cmap_cmr
+    cmrcm.cmap_cd[cm_type][cmap_cmr.name] = cmap_cmr
+
+    # Add reversed cmap to matplotlib's cmap list
+    mplcm.register_cmap(cmap=cmap_mpl_r)
+    setattr(cmrcm, cmap_cmr_r.name, cmap_cmr_r)
+    cmrcm.__all__.append(cmap_cmr_r.name)
+    cmrcm.cmap_d[cmap_cmr_r.name] = cmap_cmr_r
+    cmrcm.cmap_cd[cm_type][cmap_cmr_r.name] = cmap_cmr_r
+
+
+# Function to set the legend label of an artist that uses a colormap
+def set_cmap_legend_entry(artist, label):
+    """
+    Sets the label of the provided `artist` to `label`, and creates a legend
+    entry using a miniature version of the colormap of `artist` as the legend
+    icon.
+
+    This function can be used to add legend entries for *MPL* artists that use
+    a colormap, like those made with :func:`~matplotlib.pyplot.hexbin`;
+    :func:`~matplotlib.pyplot.hist2d`; :func:`~matplotlib.pyplot.scatter`; or
+    any :mod:`~matplotlib.pyplot` function that takes `cmap` as an input
+    argument.
+    Keep in mind that using this function will override any legend entry that
+    already exists for `artist`.
+
+    Parameters
+    ----------
+    artist : :obj:`~matplotlib.artist.Artist` object
+        Any artist object that has the `cmap` attribute, for which a legend
+        entry must be made using its colormap as the icon.
+    label : str
+        The string that must be set as the label of `artist`.
+
+    """
+
+    # Obtain the colormap of the provided artist
+    cmap = getattr(artist, 'cmap', None)
+
+    # If cmap is None, raise error
+    if cmap is None:
+        raise ValueError("Input argument 'artist' does not have attribute "
+                         "'cmap'!")
+
+    # Set the label of this artist
+    artist.set_label(label)
+
+    # Add the HandlerColorPolyCollection to the default handler map for artist
+    Legend.get_default_handler_map()[artist] = _HandlerColorPolyCollection()
+
+
+# Function to take N equally spaced colors from a colormap
+def take_cmap_colors(cmap, N, cmap_range=(0, 1), return_hex=False):
+    """
+    Takes `N` equally spaced colors from the provided colormap `cmap` and
+    returns them.
+
+    .. versionadded:: 1.3.2
+
+    Parameters
+    ----------
+    cmap : str or :obj:`~matplotlib.colors.Colormap` object
+        The registered name of the colormap in :mod:`matplotlib.cm` or its
+        corresponding :obj:`~matplotlib.colors.Colormap` object.
+    N : int
+        The number of colors to take from the provided `cmap`.
+
+    Optional
+    --------
+    cmap_range : tuple of float. Default: (0, 1)
+        The normalized value range in the colormap from which colors should be
+        taken.
+        By default, colors are taken from the entire colormap.
+    return_hex : bool. Default: False
+        If *True*, the colors are returned using their hexadecimal string
+        representations.
+        If *False*, they are instead returned as normalized RGB tuples.
+
+    Returns
+    -------
+    colors : list of tuple, str
+        The colors that were taken from the provided `cmap`.
+
+    Example
+    -------
+    Taking five equally spaced colors from the 'rainforest' colormap::
+
+        >>> take_cmap_colors('cmr.rainforest', 5)
+        [(0.0, 0.0, 0.0),
+         (0.226123592, 0.124584033, 0.562997277),
+         (0.0548210513, 0.515835251, 0.45667819),
+         (0.709615979, 0.722863985, 0.0834727592),
+         (1.0, 1.0, 1.0)]
+
+    Requesting their HEX-code values instead::
+
+        >>> take_cmap_colors('cmr.rainforest', 5, return_hex=True)
+        ['#000000', '#3a2090', '#0e8474', '#b5b815', '#ffffff']
+
+    Requesting colors in a specific range::
+
+        >>> take_cmap_colors('cmr.rainforest', 5, (0.2, 0.8), return_hex=True)
+        ['#3e0374', '#10528a', '#0e8474', '#5cad3c', '#d6bf4a']
+
+    Note
+    ----
+    Using this function on a perceptually uniform sequential colormap, like
+    those in *CMasher*, allows one to pick a number of line colors that are
+    different but still sequential. This is useful when plotting a set of lines
+    that describe the same property, but have a different initial state.
+
+    """
+
+    # Obtain the colormap
+    cmap = mplcm.get_cmap(cmap)
+
+    # Check if provided cmap_range is valid
+    if not ((0 <= cmap_range[0] <= 1) and (0 <= cmap_range[1] <= 1)):
+        raise ValueError("Input argument 'cmap_range' does not contain "
+                         "normalized values!")
+
+    # Pick colors
+    cmap_range = np.array(cmap_range)*(cmap.N-1)
+    index = np.array(np.rint(np.linspace(*cmap_range, num=N)), dtype=int)
+    colors = cmap(index)
+
+    # Convert colors to RGB tuples or hex
+    colors = list(map(to_hex if return_hex else to_rgb, colors))
+
+    # Return colors
+    return(colors)
+
+
+# %% IMPORT SCRIPT
 # Import all colormaps defined in './colormaps'
 import_cmaps(path.join(path.dirname(__file__), 'colormaps'))
